# Development

_TODO_

This documentation is work in progress.   
Reach out to [jkowalleck](https://github.com/jkowalleck) to ask for help.


## Backend

Install the requirements: `ptyhon3 -m pip install -e .[development]`.   
Then just do whatever you would like.

After writing the code have the code fixed via
[`isort`](https://pypi.org/project/isort/) and
[`autopep3`](https://pypi.org/project/autopep3/).   
These tools are already installed via `development` dependencies.

Do not forget to [test](testing.md) the code.   
This will also check for
import order (fix via `isort`) and
pycodestyle (fixevia `autopep8`).

## Image crawler

_TODO_


## Frontend

_TODO_
